==> humhub-1.11.0-beta.2.tar.gz: humhub-1.11.0-beta.2/protected/humhub/modules/user/messages/hu/base.php <==
<?php

return [
    '<strong>Followers</strong>' => 'A felhasználót <strong>követi</strong>',
    '<strong>Following</strong>' => 'A felhasználó <strong>követi</strong>',
    '<strong>Group</strong> members - {group}' => '<strong>Csoport</strong> tagok - {group}',
    '<strong>Member</strong> in these spaces' => '<strong>Tag</strong> ezekben a közösségekben',
    '<strong>User</strong> tags' => '<strong>Felhasználó</strong> cimkék',
    'All' => 'Minden',
    'Allows access to your about page with personal information' => 'Hozzáférés biztosítása a személyes információkhoz a \'Rólam\' oldaladon',
    'Auth Mode' => 'Hitelesítés módja',
    'Basic Settings' => 'Általános beállitások',
    'Change Email' => 'E-mail cím módosítása',
    'Change Password' => 'Jelszó módosítása',
    'Change Username' => 'Felhasználónév módosítása',
    'Confirm new password' => 'Új jelszó megerősítése',
    'Connect account' => 'Fiók összekapcsolása',
    'Connected Accounts' => 'Kapcsolt fiókok',
    'Connected accounts' => 'Kapcsolt fiókok',
    'Created at' => 'Létrehozva',
    'Created by' => 'Létrehozta',
    'Current password' => 'Jelenlegi jelszó',
    'Currently in use' => 'Jelenleg használatban',
    'Default Group' => 'Alapértelmezett csoport',
    'Default Space' => 'Alapértelmezett közösség',
    'Delete' => 'Törlés',
    'Delete Account' => 'Fiók törlése',
    'Description' => 'Leírás',
    'Disconnect account' => 'Fiók szétkapcsolása',
    'E-Mail is already in use! - Try forgot password.' => 'Az e-mail cím már használatban van! Próbálj visszaemlékezni a jelszóra.',
    'Email' => 'E-mail',
    'Enable Notifications' => 'Értesítések engedélyezése',
    'Follow' => 'Követés',
    'Followers' => 'Követők',
    'Following' => 'Követve',
    'Force password change upon first login' => 'A jelszó megváltoztatásának kényszerítése az első bejelentkezéskor',
    'Force password change upon next login' => 'A jelszó megváltoztatásának kényszerítése a következő bejelentkezéskor',
    'Friends' => 'Ismerősök',
    'General' => 'Általános',
    'Here you can connect to external service provider for using external services like a single sign on authentication.' => 'Itt külső szolgáltatóhoz csatlakozhatsz olyan külső szolgáltatások igénybe vételéhez, mint például az egyszeri feliratkozást igénylő hitelesítés.',
    'Language' => 'Nyelv',
    'Last Login' => 'Utolsó bejelentkezés',
    'Manager' => 'Kezelő',
    'Missing E-Mail Attribute from AuthClient.' => 'Az AuthClient-ből hiányzik az email attribútum.',
    'Missing ID AuthClient Attribute from AuthClient.' => 'Az AuthClient-ből hiányzik az AuthClient azonosító attribútum.',
    'Modules' => 'Modulok',
    'My Account' => 'Fiókom',
    'Name' => 'Név',
    'New password' => 'Új jelszó',
    'No results found!' => 'Nincs találat!',
    'No users found.' => 'Nem találhatók felhasználók.',
    'Notifications' => 'Értesítések',
    'Password' => 'Jelszó',
    'Password changed' => 'A jelszó megváltozott',
    'Password needs to be at least {chars} characters long.' => 'A jelszónak legalább {chars} karakter hosszúnak kell lennie.',
    'People' => 'Emberek',
    'Permission' => 'Engedély',
    'Profile' => 'Profil',
    'Profile posts only' => 'Csak profilbejegyzések',
    'Register now and participate!' => 'Regisztrálj és vegyél részt benne!',
    'Security' => 'Biztonság',
    'Send invite' => 'Meghívó küldése',
    'Settings' => 'Beállítások',
    'Show At Registration' => 'Mutassa a regisztrációnál',
    'Show all content' => 'Az összes tartalom megjelenítése',
    'Sign in' => 'Bejelentkezés',
    'Sign in / up' => 'Bejelentkezés / Regisztráció',
    'Sign up' => 'Regisztráció',
    'Sign up now' => 'Regisztráció most',
    'Sort order' => 'Rendezési sorrend',
    'Source' => 'Forrás',
    'Status' => 'Állapot',
    'Tags' => 'Címkék',
    'Unknown user status!' => 'Ismeretlen felhasználói állapot!',
    'Unsuccessful login attempts since last login: {failedLoginAttemptsCount}' => 'A legutóbbi bejelentkezés óta sikertelen bejelentkezési próbálkozások: {failedLoginAttemptsCount}',
    'Updated at' => 'Frissítve',
    'Updated by' => 'Frissítette',
    'User' => 'Felhasználó',
    'User has been invited.' => 'Felhasználó meghívva.',
    'Username' => 'Felhasználónév',
    'Username contains invalid characters.' => 'A felhasználónév érvénytelen karaktereket tartalmaz.',
    'View your about page' => 'Látható a Bővebben oldalon',
    'Visibility' => 'Láthatóság',
    'Visible' => 'Látható',
    'Welcome to %appName%' => 'Üdvözlünk a(z) %appName% oldalon',
    'Welcome to %appName%. Please click on the button below to proceed with your registration.' => 'Üdvözlünk a(z) %appName% oldalon. A regisztrációd befejezéséhez kattints az alábbi gombra.',
    'You got an invite' => 'Meghívód érkezett',
    'You\'re not registered.' => 'Nem vagy regisztrálva.',
    'You\'ve been invited to join {space} on {appName}' => 'Meghívást kaptál, hogy csatlakozz a(z) {space} közösséghez itt: {appName}',
    'Your account is disabled!' => 'A fiókod fel van függesztve!',
    'Your account is not approved yet!' => 'A fiókod még nincs jóváhagyva!',
    'Your are already logged in! - Logout first!' => 'Te már be vagy jelentkezve! - Először jelentkezz ki!',
    'Your new password must not be equal your current password!' => 'Az új jelszavad nem egyezhet meg a jelenlegi jelszavaddal!',
    'invited you to join {name}.' => 'meghívott, hogy csatlakozz ehhez: {name}',
    'invited you to join {space} on {name}.' => 'meghívott, hogy csatlakozz ehhez: {space} itt: {name}.',
    'or' => 'vagy',
    '<strong>Member</strong> of these Spaces' => '',
    '<strong>People</strong>' => '',
    'Allow users to mention you' => '',
    'Any' => '',
    'Find people by their profile data or user tags' => '',
    'Invited by' => '',
    'Mentioning' => '',
    'Pending Requests' => '',
    'Search...' => '',
    'Try other keywords or remove filters.' => '',
    'User Group' => '',
];

==> humhub-1.16.0-beta.2.tar.gz: humhub-1.16.0-beta.2/protected/humhub/modules/user/messages/hu/base.php <==
<?php

return [
    '<strong>Followers</strong>' => 'A felhasználót <strong>követi</strong>',
    '<strong>Following</strong>' => 'A felhasználó <strong>követi</strong>',
    '<strong>Member</strong> in these spaces' => '<strong>Tag</strong> ezekben a közösségekben',
    '<strong>Member</strong> of these Spaces' => 'Ezeknek a Közösségeknek a <strong>tagja</strong>',
    '<strong>People</strong>' => '<strong>Emberek</strong>',
    '<strong>User</strong> tags' => '<strong>Felhasználó</strong> cimkék',
    'All' => 'Minden',
    'Allow users to mention you' => 'Engedélyezd a felhasználóknak, hogy megemlítsenek',
    'Allows access to your about page with personal information' => 'Hozzáférés biztosítása a személyes információkhoz a \'Rólam\' oldaladon',
    'Any' => 'Bármi',
    'Auth Mode' => 'Hitelesítés módja',
    'Basic Settings' => 'Általános beállitások',
    'Block user' => 'Felhasználó letiltása',
    'Change Email' => 'E-mail cím módosítása',
    'Change Password' => 'Jelszó módosítása',
    'Change Username' => 'Felhasználónév módosítása',
    'Confirm new password' => 'Új jelszó megerősítése',
    'Connect account' => 'Fiók összekapcsolása',
    'Connected Accounts' => 'Kapcsolt fiókok',
    'Connected accounts' => 'Kapcsolt fiókok',
    'Created at' => 'Létrehozva',
    'Created by' => 'Létrehozta',
    'Current password' => 'Jelenlegi jelszó',
    'Currently in use' => 'Jelenleg használatban',
    'Default Group' => 'Alapértelmezett csoport',
    'Default Space' => 'Alapértelmezett közösség',
    'Delete' => 'Törlés',
    'Delete Account' => 'Fiók törlése',
    'Description' => 'Leírás',
    'Did you forget your password?' => 'Elfelejtette jelszavát?',
    'Disconnect account' => 'Fiók szétkapcsolása',
    'Edit' => 'Szerkesztés',
    'Email' => 'E-mail',
    'Enable Notifications' => 'Értesítések engedélyezése',
    'Find people by their profile data or user tags' => 'Keress embereket profiladataik vagy felhasználói címkéik alapján',
    'Follow' => 'Követés',
    'Followers' => 'Követők',
    'Following' => 'Követve',
    'Following (User)' => 'Követés (Felhasználó)',
    'Force password change upon first login' => 'A jelszó megváltoztatásának kényszerítése az első bejelentkezéskor',
    'Force password change upon next login' => 'A jelszó megváltoztatásának kényszerítése a következő bejelentkezéskor',
    'Friends' => 'Ismerősök',
    'Here you can connect to external service provider for using external services like a single sign on authentication.' => 'Itt külső szolgáltatóhoz csatlakozhatsz olyan külső szolgáltatások igénybe vételéhez, mint például az egyszeri feliratkozást igénylő hitelesítés.',
    'If this wasn\'t you, you can disregard this message.' => 'Ha ez nem Ön volt, figyelmen kívül hagyhatja ezt az üzenetet.',
    'Invite by email' => 'Meghívás e-mailben',
    'Invite by link' => 'Meghívás linken keresztül',
    'Invite new people' => 'Hívjon meg új embereket',
    'Invited by' => 'Meghívta:',
    'It looks like you clicked on an invalid password reset link. Please try again.' => 'Úgy tűnik, hogy érvénytelen jelszó-visszaállítási hivatkozásra kattintott. Kérljük próbálja újra.',
    'Language' => 'Nyelv',
    'Last Login' => 'Utolsó bejelentkezés',
    'Mentioning' => 'Említés',
    'Missing E-Mail Attribute from AuthClient.' => 'Az AuthClient-ből hiányzik az email attribútum.',
    'Missing ID AuthClient Attribute from AuthClient.' => 'Az AuthClient-ből hiányzik az AuthClient azonosító attribútum.',
    'Modules' => 'Modulok',
    'My Account' => 'Fiókom',
    'Name' => 'Név',
    'New password' => 'Új jelszó',
    'No results found!' => 'Nincs találat!',
    'No users found.' => 'Nem találhatók felhasználók.',
    'Notifications' => 'Értesítések',
    'Offline' => 'Offline',
    'Online' => 'Online',
    'Password' => 'Jelszó',
    'Password changed' => 'A jelszó megváltozott',
    'Password needs to be at least {chars} characters long.' => 'A jelszónak legalább {chars} karakter hosszúnak kell lennie.',
    'Password recovery' => 'Jelszó visszaállítása',
    'Pending Requests' => 'Függőben lévő Kérés',
    'People' => 'Emberek',
    'Permission' => 'Engedély',
    'Profile' => 'Profil',
    'Profile posts only' => 'Csak profilbejegyzések',
    'Register now and participate!' => 'Regisztrálj és vegyél részt benne!',
    'Search...' => 'Keresés...',
    'Security' => 'Biztonság',
    'Settings' => 'Beállítások',
    'Show At Registration' => 'Mutassa a regisztrációnál',
    'Show all content' => 'Az összes tartalom megjelenítése',
    'Sign in' => 'Bejelentkezés',
    'Sign in / up' => 'Bejelentkezés / Regisztráció',
    'Sign up' => 'Regisztráció',
    'Sign up now' => 'Regisztráció most',
    'Sort order' => 'Rendezési sorrend',
    'Source' => 'Forrás',
    'Status' => 'Állapot',
    'Tags' => 'Címkék',
    'The secure link has been copied in your clipboard!' => 'A biztonságos linket a vágólapra másolta!',
    'The user has been blocked for you.' => 'A felhasználót letiltották az Ön számára.',
    'The user has been unblocked for you.' => 'A felhasználó letiltását feloldották az Ön számára.',
    'Try other keywords or remove filters.' => 'Próbálj ki más kulcsszavakat, vagy távolítsd el a szűrőket.',
    'Unblock user' => 'Felhasználó feloldása',
    'Unknown user status!' => 'Ismeretlen felhasználói állapot!',
    'Unsuccessful login attempts since last login: {failedLoginAttemptsCount}' => 'A legutóbbi bejelentkezés óta sikertelen bejelentkezési próbálkozások: {failedLoginAttemptsCount}',
    'Updated at' => 'Frissítve',
    'Updated by' => 'Frissítette',
    'User' => 'Felhasználó',
    'User Group' => 'Felhasználói Csoport',
    'User has been invited.' => 'Felhasználó meghívva.',
    'Username' => 'Felhasználónév',
    'Username contains invalid characters.' => 'A felhasználónév érvénytelen karaktereket tartalmaz.',
    'View your about page' => 'Látható a Bővebben oldalon',
    'Visibility' => 'Láthatóság',
    'Visible' => 'Látható',
    'Welcome to %appName%' => 'Üdvözlünk a(z) %appName% oldalon',
    'Welcome to %appName%. Please click on the button below to proceed with your registration.' => 'Üdvözlünk a(z) %appName% oldalon. A regisztrációd befejezéséhez kattints az alábbi gombra.',
    'Whenever a user follows another user.' => 'Amikor egy felhasználó követ egy másik felhasználót.',
    'You got an invite' => 'Meghívód érkezett',
    'You tried registering an account with %appName%, but already have an account associated with this email address.' => 'Megpróbált regisztrálni egy fiókot a %appName% szolgáltatással, de már van fiókja társítva ehhez az e-mail címhez.',
    'You\'re not registered.' => 'Nem vagy regisztrálva.',
    'You\'ve been invited to join {space} on {appName}' => 'Meghívást kaptál, hogy csatlakozz a(z) {space} közösséghez itt: {appName}',
    'Your account is disabled!' => 'A fiókod fel van függesztve!',
    'Your account is not approved yet!' => 'A fiókod még nincs jóváhagyva!',
    'Your are already logged in! - Logout first!' => 'Te már be vagy jelentkezve! - Először jelentkezz ki!',
    'Your new password must not be equal your current password!' => 'Az új jelszavad nem egyezhet meg a jelenlegi jelszavaddal!',
    'invited you to join {name}.' => 'meghívott, hogy csatlakozz ehhez: {name}',
    'invited you to join {space} on {name}.' => 'meghívott, hogy csatlakozz ehhez: {space} itt: {name}.',
    'or' => 'vagy',
    'Advanced Profile Search' => '',
    'Group Manager(s)' => '',
    'The Group Manager can approve pending registrations of this group.' => '',
];
